@@ -1,10 +1,7 @@
 """Authentication module exports"""
+
 from .auth import AuthBase
 from .no_auth import NoAuth
 from .local_profile_auth import LocalProfileAuth
 
-__all__ = [
-    "AuthBase",
-    "NoAuth", 
-    "LocalProfileAuth"
-]
+__all__ = ["AuthBase", "NoAuth", "LocalProfileAuth"]
