@@ -1,8 +1,4 @@
 from .event_handler import EventHandler, Event
 from .event_types import EVENT_LIST
 
-__all__ = [
-    "EventHandler",
-    "Event",
-    "EVENT_LIST"
-]
+__all__ = ["EventHandler", "Event", "EVENT_LIST"]
